@@ -17,6 +17,7 @@ from .scheduling import (
 )
 
 AIR_INFRA = "airInfra"
+MODEL_POSTFIX = ":latest"
 
 
 def retrieve_infra_model_assets(client) -> Iterator[Asset]:
@@ -45,7 +46,8 @@ def create_asset(client, asset: Asset) -> str:
         parent_external_id=asset.external_id,
         metadata={"data": data},
     )
-    client.assets.create(asset_to_create)
+    if client.assets.retrieve(external_id=hashed) is not None:
+        client.assets.create(asset_to_create)
     return hashed
 
 
@@ -95,18 +97,23 @@ def delete_double_schedules(client: CogniteClient, model_names: List):
             [client.functions.schedules.delete(j.id) for j in delete_ids]
 
 
+def functions_exist_and_ready_external_ids(client: CogniteClient) -> List[str]:
+    functions = client.functions.list()
+    ready_air_functions = [f.external_ids for f in functions if f.owner == "AIR" and f.status == "Ready"]
+    return ready_air_functions
+
+
 def execute(client: CogniteClient):
     missing_schedule_assets = retrieve_schedule_asset_without_asset(client)
     [create_asset(client, asset) for asset in missing_schedule_assets]
     to_be_deployed = retrieve_undeployed_infra_schedule_assets(client)
+    existing_air_functions = functions_exist_and_ready_external_ids(client)
     # check if function exists
-    existing_deployed = [
-        model for model in to_be_deployed if client.functions.retrieve(external_id=model.function_external_id)
-    ]
+    existing_deployed = [model for model in to_be_deployed if model.model + MODEL_POSTFIX in existing_air_functions]
     if len(existing_deployed):
         create_schedules(client, existing_deployed)
     updated, to_be_deleted = retrieve_updated_infra_schedules(client)
-    existing_updated = [model for model in updated if client.functions.retrieve(external_id=model.function_external_id)]
+    existing_updated = [model for model in updated if model.model + MODEL_POSTFIX in existing_air_functions]
     if len(existing_updated):
         update_schedules(client, existing_updated, to_be_deleted)
     print(f"Created: {len(existing_deployed)}, Updated: {len(existing_updated)}")
