@@ -16,7 +16,7 @@ os.environ["COGNITE_TIMEOUT"] = "120"
 def data_set_id(client: CogniteClient, name: str) -> int:
     data_sets = client.data_sets.list(limit=-1).dump()
     for ds in data_sets:
-        if ds["name"] == "AIR" and "archived" not in ds["metadata"]:
+        if ds["name"] == name and "archived" not in ds["metadata"]:
             return ds["id"]
 
     raise LookupError(f"Not able to find dataset named {name}")
